@@ -5,23 +5,29 @@
 
 /* Package information */
 #define PACKAGE           "task"
-#define VERSION           "2.3.0"
+#define VERSION           "2.5.0"
 #define PACKAGE_BUGREPORT "support@taskwarrior.org"
 #define PACKAGE_NAME      "task"
 #define PACKAGE_TARNAME   "task"
-#define PACKAGE_VERSION   "2.3.0"
-#define PACKAGE_STRING    "task 2.3.0"
+#define PACKAGE_VERSION   "2.5.0"
+#define PACKAGE_STRING    "task 2.5.0"
+
+#define CMAKE_BUILD_TYPE  ""
 
 /* Installation details */
 #define TASK_RCDIR "/usr/local/share/doc/task/rc"
 
 /* Localization */
-#define PACKAGE_LANGUAGE  1
-#define LANGUAGE_EN_US 1
-#define LANGUAGE_ES_ES 2
-#define LANGUAGE_FR_FR 4
-#define LANGUAGE_DE_DE 3
-#define LANGUAGE_IT_IT 5
+#define PACKAGE_LANGUAGE 1
+#define LANGUAGE_ENG_USA 1
+#define LANGUAGE_ESP_ESP 2
+#define LANGUAGE_FRA_FRA 4
+#define LANGUAGE_DEU_DEU 3
+#define LANGUAGE_ITA_ITA 5
+#define LANGUAGE_POR_PRT 6
+#define LANGUAGE_EPO_RUS 7
+#define LANGUAGE_POL_POL 8
+#define LANGUAGE_JPN_JPN 9
 
 /* git information */
 #define HAVE_COMMIT
@@ -46,12 +52,6 @@
 /* Found the GnuTLS library */
 #define HAVE_LIBGNUTLS
 
-/* Found the Readline library */
-/* #undef HAVE_READLINE */
-
-/* Found the pthread library */
-/* #undef HAVE_LIBPTHREAD */
-
 /* Found tm_gmtoff */
 #define HAVE_TM_GMTOFF
 
