@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +24,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <iostream>
 #include <iomanip>
 #include <sstream>
@@ -114,3 +112,11 @@ void Timer::subtract (unsigned long value)
 }
 
 ////////////////////////////////////////////////////////////////////////////////
+unsigned long Timer::now ()
+{
+  struct timeval now;
+  gettimeofday (&now, NULL);
+  return now.tv_sec * 1000000 + now.tv_usec;
+}
+
+////////////////////////////////////////////////////////////////////////////////
