@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +24,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <ColEnd.h>
 #include <i18n.h>
 
@@ -43,9 +41,3 @@ ColumnEnd::~ColumnEnd ()
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-bool ColumnEnd::validate (std::string& value)
-{
-  return ColumnDate::validate (value);
-}
-
-////////////////////////////////////////////////////////////////////////////////
