@@ -1,7 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
-// taskwarrior - a command line task list manager.
 //
-// Copyright 2006-2013, Paul Beckingham, Federico Hernandez.
+// Copyright 2006 - 2015, Paul Beckingham, Federico Hernandez.
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -25,8 +24,7 @@
 //
 ////////////////////////////////////////////////////////////////////////////////
 
-#define L10N                                           // Localization complete.
-
+#include <cmake.h>
 #include <algorithm>
 #include <Context.h>
 #include <ColTags.h>
@@ -39,19 +37,14 @@ extern Context context;
 ////////////////////////////////////////////////////////////////////////////////
 ColumnTags::ColumnTags ()
 {
-  _name  = "tags";
-  _type  = "string";
-  _style = "list";
-  _label = STRING_COLUMN_LABEL_TAGS;
-
-  _styles.push_back ("list");
-  _styles.push_back ("indicator");
-  _styles.push_back ("count");
-
-  _examples.push_back (STRING_COLUMN_EXAMPLES_TAGS);
-  _examples.push_back (context.config.get ("tag.indicator"));
-  _examples.push_back ("[2]");
-
+  _name      = "tags";
+  _type      = "string";
+  _style     = "list";
+  _label     = STRING_COLUMN_LABEL_TAGS;
+  _styles    = {"list", "indicator", "count"};
+  _examples  = {STRING_COLUMN_EXAMPLES_TAGS,
+                context.config.get ("tag.indicator"),
+                "[2]"};
   _hyphenate = context.config.getBoolean ("hyphenate");
 }
 
@@ -60,12 +53,6 @@ ColumnTags::~ColumnTags ()
 {
 }
 
-////////////////////////////////////////////////////////////////////////////////
-bool ColumnTags::validate (std::string& value)
-{
-  return true;
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // Overriden so that style <----> label are linked.
 // Note that you can not determine which gets called first.
@@ -86,30 +73,42 @@ void ColumnTags::setStyle (const std::string& value)
 // Set the minimum and maximum widths for the value.
 void ColumnTags::measure (Task& task, unsigned int& minimum, unsigned int& maximum)
 {
-       if (_style == "indicator") minimum = maximum = utf8_width (context.config.get ("tag.indicator"));
-  else if (_style == "count")     minimum = maximum = 3;
-  else if (_style == "default" ||
-           _style == "list")
-  {
-    std::string tags = task.get (_name);
-    minimum = 0;
-    maximum = utf8_width (tags);
+  minimum = maximum = 0;
 
-    if (maximum)
+  if (task.has (_name))
+  {
+    if (_style == "indicator")
     {
-      std::vector <std::string> all;
-      split (all, tags, ',');
-      std::vector <std::string>::iterator i;
-      for (i = all.begin (); i != all.end (); ++i)
+      if (task.has ("tags"))
+        minimum = maximum = utf8_width (context.config.get ("tag.indicator"));
+      else
+        minimum = maximum = 0;
+    }
+    else if (_style == "count")
+    {
+      minimum = maximum = 3;
+    }
+    else if (_style == "default" ||
+             _style == "list")
+    {
+      std::string tags = task.get (_name);
+      maximum = utf8_width (tags);
+
+      if (maximum)
       {
-        unsigned int length = utf8_width (*i);
-        if (length > minimum)
-          minimum = length;
+        std::vector <std::string> all;
+        split (all, tags, ',');
+        for (auto& i : all)
+        {
+          unsigned int length = utf8_width (i);
+          if (length > minimum)
+            minimum = length;
+        }
       }
     }
+    else
+      throw format (STRING_COLUMN_BAD_FORMAT, _name, _style);
   }
-  else
-    throw format (STRING_COLUMN_BAD_FORMAT, _name, _style);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -119,19 +118,25 @@ void ColumnTags::render (
   int width,
   Color& color)
 {
-  std::string tags = task.get (_name);
-  if (tags != "")
+  if (task.has (_name))
   {
+    std::string tags = task.get (_name);
     if (_style == "default" ||
         _style == "list")
     {
-      std::replace (tags.begin (), tags.end (), ',', ' ');
+      std::vector <std::string> allTags;
+      split (allTags, tags, ',');
+      if (allTags.size () > 1)
+      {
+        std::sort (allTags.begin (), allTags.end ());
+        join (tags, " ", allTags);
+      }
+
       std::vector <std::string> all;
       wrapText (all, tags, width, _hyphenate);
 
-      std::vector <std::string>::iterator i;
-      for (i = all.begin (); i != all.end (); ++i)
-        lines.push_back (color.colorize (leftJustify (*i, width)));
+      for (auto& i : all)
+        lines.push_back (color.colorize (leftJustify (i, width)));
     }
     else if (_style == "indicator")
     {
